@@ -1,5 +1,5 @@
 __name__ = "socket_api2"
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 __author__ = "Da4ndo"
 __discord__ = "Da4ndo#0934"
@@ -281,7 +281,7 @@ class Server():
                 conn, addr = self.server.accept()
                 if self.console_output: outstr("ACCESS", f"Connection from {addr} has been established!", start="\n")
 
-                new_client = _ClientOOP(ip=addr, conn=conn, console_output=self.console_output, tiemout=self.client_timeout)
+                new_client = _ClientOOP(ip=addr, conn=conn, console_output=self.console_output, timeout=self.client_timeout)
                 self.clients.append(new_client)
 
                 for func in self.decorator_functions_call:
@@ -295,7 +295,7 @@ class Server():
             if not client.check_connection():
                 self.clients.remove(client)
                 if self.console_output: outstr("DEBUG", f"{client.ip} is no longer connected. (Disconnect)")
-                for func in self.decorator_functions_call:
+                for func in self.decorator_client_disconnect:
                     _thread.start_new_thread(func, (client,))
 
         while True:
